"""Tests for nbformat corpus"""

# Copyright (c) Jupyter Development Team.
# Distributed under the terms of the Modified BSD License.

from .. import words


def test_generate_corpus_id(recwarn):
    assert len(words.generate_corpus_id()) > 7
    # 1 in 4294967296 (2^32) times this will fail
    assert words.generate_corpus_id() != words.generate_corpus_id()
    assert len(recwarn) == 0



import os
from base64 import encodebytes

from nbformat.v3.nbbase import (
    nbformat,
    nbformat_minor,
    new_author,
    new_code_cell,
    new_heading_cell,
    new_metadata,
    new_notebook,
    new_output,
    new_text_cell,
    new_worksheet,
)

# some random base64-encoded *text*
png = encodebytes(os.urandom(5)).decode("ascii")
jpeg = encodebytes(os.urandom(6)).decode("ascii")

ws = new_worksheet()

ws.cells.append(
    new_text_cell(
        "html",
        source="Some NumPy Examples",
    )
)


ws.cells.append(new_code_cell(input="import numpy", prompt_number=1, collapsed=False))

ws.cells.append(
    new_text_cell(
        "markdown",
        source="A random array",
    )
)

ws.cells.append(
    new_text_cell(
        "raw",
        source="A random array",
    )
)

ws.cells.append(new_heading_cell("My Heading", level=2))

ws.cells.append(new_code_cell(input="a = numpy.random.rand(100)", prompt_number=2, collapsed=True))
ws.cells.append(
    new_code_cell(
        input="a = 10\nb = 5\n",
        prompt_number=3,
    )
)
ws.cells.append(
    new_code_cell(
        input="a = 10\nb = 5",
        prompt_number=4,
    )
)

ws.cells.append(
    new_code_cell(
        input='print "ünîcødé"',
        prompt_number=3,
        collapsed=False,
        outputs=[
            new_output(
                output_type="pyout",
                output_text="<array a>",
                output_html="The HTML rep",
                output_latex="$a$",
                output_png=png,
                output_jpeg=jpeg,
                output_svg="<svg>",
                output_json='{"json": "data"}',
                output_javascript="var i=0;",
                prompt_number=3,
            ),
            new_output(
                output_type="display_data",
                output_text="<array a>",
                output_html="The HTML rep",
                output_latex="$a$",
                output_png=png,
                output_jpeg=jpeg,
                output_svg="<svg>",
                output_json='{"json": "data"}',
                output_javascript="var i=0;",
            ),
            new_output(
                output_type="pyerr",
                ename="NameError",
                evalue="NameError was here",
                traceback=["frame 0", "frame 1", "frame 2"],
            ),
            new_output(output_type="stream", output_text="foo\rbar\r\n"),
            new_output(output_type="stream", stream="stderr", output_text="\rfoo\rbar\n"),
        ],
    )
)

authors = [
    new_author(
        name="Bart Simpson", email="bsimpson@fox.com", affiliation="Fox", url="http://www.fox.com"
    )
]
md = new_metadata(
    name="My Notebook",
    license="BSD",
    created="8601_goes_here",
    modified="8601_goes_here",
    gistid="21341231",
    authors=authors,
)

nb0 = new_notebook(worksheets=[ws, new_worksheet()], metadata=md)

nb0_py = """# -*- coding: utf-8 -*-
# <nbformat>%i.%i</nbformat>

# <htmlcell>

# Some NumPy Examples

# <codecell>

import numpy

# <markdowncell>

# A random array

# <rawcell>

# A random array

# <headingcell level=2>

# My Heading

# <codecell>

a = numpy.random.rand(100)

# <codecell>

a = 10
b = 5

# <codecell>

a = 10
b = 5

# <codecell>

print "ünîcødé"

""" % (
    nbformat,
    nbformat_minor,
)



from nbformat.v1.nbbase import new_code_cell, new_notebook, new_text_cell

nb0 = new_notebook()

nb0.cells.append(new_text_cell(text="Some NumPy Examples"))


nb0.cells.append(new_code_cell(code="import numpy", prompt_number=1))

nb0.cells.append(new_code_cell(code="a = numpy.random.rand(100)", prompt_number=2))

nb0.cells.append(new_code_cell(code="print a", prompt_number=3))



"""The main API for the v3 notebook format.
"""

# Copyright (c) IPython Development Team.
# Distributed under the terms of the Modified BSD License.

__all__ = [
    "NotebookNode",
    "new_code_cell",
    "new_text_cell",
    "new_notebook",
    "new_output",
    "new_worksheet",
    "new_metadata",
    "new_author",
    "new_heading_cell",
    "nbformat",
    "nbformat_minor",
    "nbformat_schema",
    "reads_json",
    "writes_json",
    "read_json",
    "write_json",
    "to_notebook_json",
    "reads_py",
    "writes_py",
    "read_py",
    "write_py",
    "to_notebook_py",
    "downgrade",
    "upgrade",
    "parse_filename",
]

import os

from .convert import downgrade, upgrade
from .nbbase import (
    NotebookNode,
    nbformat,
    nbformat_minor,
    nbformat_schema,
    new_author,
    new_code_cell,
    new_heading_cell,
    new_metadata,
    new_notebook,
    new_output,
    new_text_cell,
    new_worksheet,
)
from .nbjson import reads as read_json
from .nbjson import reads as reads_json
from .nbjson import to_notebook as to_notebook_json
from .nbjson import writes as write_json
from .nbjson import writes as writes_json
from .nbpy import reads as read_py
from .nbpy import reads as reads_py
from .nbpy import to_notebook as to_notebook_py
from .nbpy import writes as write_py
from .nbpy import writes as writes_py


def parse_filename(fname):
    """Parse a notebook filename.

    This function takes a notebook filename and returns the notebook
    format (json/py) and the notebook name. This logic can be
    summarized as follows:

    * notebook.ipynb -> (notebook.ipynb, notebook, json)
    * notebook.json  -> (notebook.json, notebook, json)
    * notebook.py    -> (notebook.py, notebook, py)
    * notebook       -> (notebook.ipynb, notebook, json)

    Parameters
    ----------
    fname : unicode
        The notebook filename. The filename can use a specific filename
        extention (.ipynb, .json, .py) or none, in which case .ipynb will
        be assumed.

    Returns
    -------
    (fname, name, format) : (unicode, unicode, unicode)
        The filename, notebook name and format.
    """
    basename, ext = os.path.splitext(fname)
    if ext == ".ipynb":
        format = "json"
    elif ext == ".json":
        format = "json"
    elif ext == ".py":
        format = "py"
    else:
        basename = fname
        fname = fname + ".ipynb"
        format = "json"
    return fname, basename, format



"""
Contains base test class for nbformat
"""

# Copyright (c) IPython Development Team.
# Distributed under the terms of the Modified BSD License.

import os
import unittest


class TestsBase(unittest.TestCase):
    """Base tests class."""

    @classmethod
    def fopen(cls, f, mode="r", encoding="utf-8"):
        return open(os.path.join(cls._get_files_path(), f), mode, encoding=encoding)

    @classmethod
    def _get_files_path(cls):
        return os.path.dirname(__file__)
